@@ -1,15 +1,15 @@
 #
 # This file is part of DBIx-Class-Graph
 #
-# This software is Copyright (c) 2010 by Moritz Onken.
+# This software is Copyright (c) 2011 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package DBIx::Class::Graph::Role::ResultSet;
-BEGIN {
-  $DBIx::Class::Graph::Role::ResultSet::VERSION = '1.03';
+{
+  $DBIx::Class::Graph::Role::ResultSet::VERSION = '1.04';
 }
 
 use strict;
@@ -28,40 +28,41 @@ has _graph => (
 has _graph_rel => ( is => 'rw' );
 
 sub _import_methods {
-    return
-      map { $_ => $_ }
-      grep { $_ ne 'new' && $_ !~ /^_/ } $_[1]->get_all_method_names;
+    return map { $_ => $_ }
+        grep { $_ ne 'new' && $_ !~ /^_/ && !__PACKAGE__->can($_) }
+        $_[1]->get_all_method_names;
 }
 
 sub _build__graph {
     my $self   = shift;
     my $source = $self->result_class;
-    my ( $pkey ) = $source->primary_columns;
+    my ($pkey) = $source->primary_columns;
     my $rel    = $source->_graph_rel;
-    my @obj = $self->search( undef, { prefetch => $rel } )->all;
+    my @obj    = $self->search( undef, { prefetch => $rel } )->all;
     $self->set_cache( \@obj );
     my $g = DBIx::Class::Graph::Wrapper->new( refvertexed => 1 );
 
     for (@obj) {
         $g->add_vertex($_);
         $_->_graph($g);
-        weaken($_->{_graph});
-        
+        weaken( $_->{_graph} );
+
     }
-    
+
     $g->[99] = 1;
     foreach my $row (@obj) {
         my ( $from, $to ) = ();
         my $col = $source->_graph_column;
-        if ( $row->result_source->has_column( $col ) ) {
+        if ( $row->result_source->has_column($col) ) {
             next
-              unless ( my $pre = {$row->get_columns}->{ $source->_graph_column } );
-            ( $from, $to ) =
-              ( $g->get_vertex( $row->$pkey ), $g->get_vertex($pre) );
+                unless ( my $pre
+                = { $row->get_columns }->{ $source->_graph_column } );
+            ( $from, $to )
+                = ( $g->get_vertex( $row->$pkey ), $g->get_vertex($pre) );
             next unless $from && $to;
 
             ( $from, $to ) = ( $to, $from )
-              if $source->_connect_by eq "predecessor";
+                if $source->_connect_by eq "predecessor";
             $g->add_edge( $from, $to );
         }
         else {
@@ -69,12 +70,13 @@ sub _build__graph {
                 ( $from, $to ) = (
                     $g->get_vertex( $row->$pkey ),
                     $g->get_vertex(
-                        { $pre->get_columns }->{ $source->_graph_foreign_column }
+                        { $pre->get_columns }
+                        ->{ $source->_graph_foreign_column }
                     )
                 );
                 next unless $from && $to;
                 ( $from, $to ) = ( $to, $from )
-                  if $source->_connect_by eq "predecessor";
+                    if $source->_connect_by eq "predecessor";
                 $g->add_edge( $from, $to );
 
             }
@@ -86,6 +88,7 @@ sub _build__graph {
 }
 
 1;
+
 __END__
 =pod
 
@@ -95,7 +98,7 @@ DBIx::Class::Graph::Role::ResultSet
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =head1 AUTHOR
 
@@ -103,7 +106,7 @@ Moritz Onken <onken@netcubed.de>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Moritz Onken.
+This software is Copyright (c) 2011 by Moritz Onken.
 
 This is free software, licensed under:
 
