@@ -1,7 +1,7 @@
 #
 # This file is part of DBIx-Class-Graph
 #
-# This software is Copyright (c) 2010 by Moritz Onken.
+# This software is Copyright (c) 2011 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
@@ -12,8 +12,8 @@ package
 
 use base 'DBIx::Class';
 
-__PACKAGE__->load_components qw(Graph Core);
-__PACKAGE__->table qw(simple_succ);
+__PACKAGE__->load_components(qw(Graph Core));
+__PACKAGE__->table(qw(simple_succ));
 __PACKAGE__->add_columns(
     title   => { data_type => "character varying", },
     childid => {
@@ -23,7 +23,7 @@ __PACKAGE__->add_columns(
     id => { data_type => "integer", }
 );
 
-__PACKAGE__->set_primary_key qw(id);
+__PACKAGE__->set_primary_key(qw(id));
 
 __PACKAGE__->connect_graph( successor => "childid" );
 
